@@ -8,7 +8,7 @@ use warnings;
 use Carp;
 use Exporter qw{ import };
 
-our $VERSION = '0.047_01';
+our $VERSION = '0.035';
 
 our @EXPORT_OK = qw{ __any };
 
@@ -89,7 +89,7 @@ If not, it is capable of generating an explanatory message.
 
 I am using this rather than the usual install tools' recommendation
 machinery for greater flexibility, and because I personally have found
-their output rather Draconian, and my correspondence indicates that my
+their output rather Draconian, and my correspondance indicates that my
 users do too.
 
 =head1 METHODS
@@ -144,9 +144,7 @@ modules are needed it returns nothing.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-SIMBAD-Client>,
-L<https://github.com/trwyant/perl-Astro-SIMBAD-Client/issues>, or in
-electronic mail to the author.
+L<http://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -154,11 +152,11 @@ Tom Wyant (wyant at cpan dot org)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016-2025 by Thomas R. Wyant, III
+Copyright (C) 2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
-of the licenses in the files F<LICENSE-Artistic> and F<LICENSE-GNU>.
+of the licenses in the directory LICENSES.
 
 This program is distributed in the hope that it will be useful, but
 without any warranty; without even the implied warranty of
