@@ -4,16 +4,9 @@ use strict;
 use warnings;
 
 use Astro::SIMBAD::Client;
-use Test::More 0.96;	# Because of subtest()
+use Test::More 0.88;
 
-use Exporter ();
-our @ISA = qw{ Exporter };
-
-our @CARP_NOT = ( qw{ Astro::SIMBAD::Client } );
-
-use constant ARRAY_REF	=> ref [];
-use constant HASH_REF	=> ref {};
-use constant REGEXP_REF	=> ref qr{};
+use base qw{ Exporter };
 
 our @EXPORT_OK = qw{
     access
@@ -29,7 +22,6 @@ our @EXPORT_OK = qw{
     echo
     end
     find
-    have_scheme
     hidden
     load_data
     load_module
@@ -39,7 +31,6 @@ our @EXPORT_OK = qw{
     plan
     returned_value
     silent
-    subtest
     test
     test_false
     $TODO
@@ -54,54 +45,54 @@ my $ref;	# Reference to result of method call, if it is a reference.
 my $skip;	# True to skip tests.
 my $silent;	# True to silence exceptions if $skip is true.
 
-sub access {
+sub access () {	## no critic (ProhibitSubroutinePrototypes)
     eval {
 	require LWP::UserAgent;
 	1;
     } or plan skip_all => 'Can not load LWP::UserAgent';
-    my $resp = LWP::UserAgent->new(
-    )->get( Astro::SIMBAD::Client->__build_url( 'simbad/' ) );
+    my $svr = Astro::SIMBAD::Client->get ('server');
+    my $resp = LWP::UserAgent->new->get ("http://$svr/simbad/");
     $resp->is_success
 	or plan skip_all => "@{[$resp->status_line]}";
     return;
 }
 
-sub call {
+sub call (@) {	## no critic (ProhibitSubroutinePrototypes)
     my ( $method, @args ) = @_;
     $obj ||= Astro::SIMBAD::Client->new();
     eval {
 	$got = $obj->$method( @args );
 	1;
     } or do {
-	_method_failure( $method, @args );
+	_method_failure( $method );
 	$got = $@;
     };
     $ref = ref $got ? $got : undef;
     return;
 }
 
-sub call_a {
+sub call_a (@) {	## no critic (ProhibitSubroutinePrototypes)
     my ( $method, @args ) = @_;
     $obj ||= Astro::SIMBAD::Client->new();
     eval {
 	$got = [ $obj->$method( @args ) ];
 	1;
     } or do {
-	_method_failure( $method. @args );
+	_method_failure( $method );
 	$got = $@;
     };
     $ref = ref $got ? $got : undef;
     return;
 }
 
-sub canned {
+sub canned (@) {	## no critic (ProhibitSubroutinePrototypes)
     my ( @args ) = @_;
     my $want = $canned;
     foreach my $key (@args) {
 	my $ref = ref $want;
-	if ( ARRAY_REF eq $ref ) {
+	if ($ref eq 'ARRAY') {
 	    $want = $want->[$key];
-	} elsif ( HASH_REF eq $ref ) {
+	} elsif ($ref eq 'HASH') {
 	    $want = $want->{$key};
 	} elsif ($ref) {
 	    die "Loaded data contains unexpected $ref reference for key $key\n";
@@ -112,15 +103,15 @@ sub canned {
     return $want;
 }
 
-sub clear {
+sub clear (@) {	## no critic (ProhibitSubroutinePrototypes)
     $got = $ref = undef;	# clear
     $skip = undef;		# noskip
     $silent = undef;		# Not silent.
     return;
 }
 
-sub count {
-    if ( ARRAY_REF eq ref $got ) {
+sub count () {	## no critic (ProhibitSubroutinePrototypes)
+    if ( 'ARRAY' eq ref $got ) {
 	$got = @{ $got };
     } else {
 	$got = undef;
@@ -128,18 +119,18 @@ sub count {
     return;
 }
 
-sub deref {
+sub deref (@) {	## no critic (ProhibitSubroutinePrototypes)
     $got = $ref;
     goto &deref_curr;
 }
 
-sub deref_curr {
+sub deref_curr (@) {	## no critic (ProhibitSubroutinePrototypes)
     my ( @args ) = @_;
     foreach my $key (@args) {
 	my $type = ref $got;
-	if ( ARRAY_REF eq $type ) {
+	if ($type eq 'ARRAY') {
 	    $got = $got->[$key];
-	} elsif ($type eq HASH_REF) {
+	} elsif ($type eq 'HASH') {
 	    $got = $got->{$key};
 	} else {
 	    $got = undef;
@@ -148,13 +139,13 @@ sub deref_curr {
     return;
 }
 
-sub dumper {
+sub dumper () {	## no critic (ProhibitSubroutinePrototypes)
 	require Data::Dumper;
 	diag Data::Dumper::Dumper( $got );
     return;
 }
 
-sub echo {
+sub echo (@) {	## no critic (ProhibitSubroutinePrototypes)
     my @args = @_;
     foreach ( @args ) {
 	note $_;
@@ -162,22 +153,22 @@ sub echo {
     return;
 }
 
-sub end {
+sub end () {	## no critic (ProhibitSubroutinePrototypes)
     done_testing;
     return;
 }
 
-sub find {
+sub find (@) {	## no critic (ProhibitSubroutinePrototypes)
     my ( @args ) = @_;
     my $target = pop @args;
-    if ( ARRAY_REF eq ref $got ) {
+    if (ref $got eq 'ARRAY') {
 	foreach my $item ( @{ $got } ) {
 	    my $test = $item;
 	    foreach my $key ( @args ) {
 		my $type = ref $test;
-		if ( ARRAY_REF eq $type ) {
+		if ($type eq 'ARRAY') {
 		    $test = $test->[$key];
-		} elsif ( HASH_REF eq $type ) {
+		} elsif ($type eq 'HASH') {
 		    $test = $test->{$key};
 		} else {
 		    $test = undef;
@@ -190,34 +181,33 @@ sub find {
     return;
 }
 
-sub have_scheme {
-    my ( $protocol ) = @_;
-    local $@ = undef;
-    return eval {
-	require "LWP/Protocol/$protocol.pm";
-	1;
-    };
-}
-
-sub hidden {
+sub hidden ($) {
     my ( $module ) = @_;
     my $code = Test::Without::Module->can( 'get_forbidden_list' )
 	or return 0;
     return exists $code->()->{$module} || 0;
 }
 
-sub load_data {
-    my ( $arg ) = @_;
-    if ( defined $arg ) {
-	local @INC = ( @INC, '.' );
-	$canned = do $arg;
+sub load_data ($) {	## no critic (ProhibitSubroutinePrototypes)
+    my ( @args ) = @_;
+    if ( @args ) {
+	my $fn = $args[0];
+	open (my $fh, '<', $fn) or die "Failed to open $fn: $!\n";
+	local $/ = undef;
+	# Perl::Critic does not like string evals, but the
+	# following needs to load arbitrary data dumped with
+	# Data::Dumper. I could switch to YAML, but that is
+	# not a core module.
+	$canned = eval scalar <$fh>;	## no critic (ProhibitStringyEval)
+	$canned or die $@;
+	close $fh;
     } else {
 	$canned = undef;
     }
     return;
 }
 
-sub load_module {
+sub load_module (@) {	## no critic (ProhibitSubroutinePrototypes)
     my @args = @_;
     my $prob = @args > 1 ?
 	("Can not load any of " . join (', ', @args)) :
@@ -243,7 +233,7 @@ sub load_module {
     return;
 }
 
-sub load_module_or_skip_all {
+sub load_module_or_skip_all (@) {
     my @args = @_;
     load_module( @args );
     $skip
@@ -251,7 +241,7 @@ sub load_module_or_skip_all {
     return;
 }
 
-sub module_loaded {		## no critic (RequireArgUnpacking)
+sub module_loaded (@) {		## no critic (ProhibitSubroutinePrototypes,RequireArgUnpacking)
     my ( @args ) = @_;
     $loaded{shift @args} or return;
     my $verb = shift @args;
@@ -261,11 +251,11 @@ sub module_loaded {		## no critic (RequireArgUnpacking)
     goto &$code;
 }
 
-sub returned_value {
+sub returned_value () { ## no critic (ProhibitSubroutinePrototypes,RequireArgUnpacking)
     return $got;
 }
 
-sub silent {
+sub silent (;$) { ## no critic (ProhibitSubroutinePrototypes)
     my ( $arg ) = @_;
     defined $arg
 	or $arg = ! $silent;
@@ -273,16 +263,17 @@ sub silent {
     return;
 }
 
-sub test {		## no critic (RequireArgUnpacking)
+sub test ($$) {		## no critic (ProhibitSubroutinePrototypes,RequireArgUnpacking)
     $_[2] = 1;
     goto &_test;
 }
 
-sub test_false {	## no critic (RequireArgUnpacking)
+sub test_false ($$) {	## no critic (ProhibitSubroutinePrototypes,RequireArgUnpacking)
     $_[2] = 0;
     goto &_test;
 }
 
+
 sub _test {		## no critic (RequireArgUnpacking)
     my ( $want, $title, $type ) = @_;
     $got = 'undef' unless defined $got;
@@ -295,7 +286,7 @@ sub _test {		## no critic (RequireArgUnpacking)
 	SKIP: {
 	    skip $skip, 1;
 	}
-    } elsif ( REGEXP_REF eq ref $want ) {
+    } elsif (ref $want eq 'Regexp') {
 	@_ = ( $got, $want, $title );
 	goto $type ? \&like : \&unlike;
     } elsif (_numberp ($want) && _numberp ($got)) {
@@ -311,14 +302,12 @@ sub _test {		## no critic (RequireArgUnpacking)
 ##################################################################
 
 sub _method_failure {
-    my ( $method, @args ) = @_;
+    my ( $method ) = @_;
     $skip
 	and $silent
 	and return;
     my $msg = $skip ? ' ($skip set)' : '';
-    @args = map { _quote() } @args;
-    local $" = ', ';
-    diag "$method( @args ) failed$msg: $@";
+    diag "$method failed$msg: $@";
     return;
 }
 
@@ -326,15 +315,6 @@ sub _numberp {
     return ($_[0] =~ m/^([+-]?)(?=\d|\.\d)\d*(\.\d*)?([Ee]([+-]?\d+))?$/);
 }
 
-sub _quote {
-    defined $_
-	or return 'undef';
-    _numberp( $_ )
-	and return $_;
-    s/ ( ['\\] ) /\\$1/smx;
-    return "'$_'";
-}
-
 1;
 
 __END__
@@ -512,24 +492,17 @@ the C<Test::More> C<like()> subroutine. If it looks like a number, the
 comparison is done with C<cmp_ok> for numeric equality. Otherwise, the
 comparison is done with C<is>.
 
-=head1 SUPPORT
-
-Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-SIMBAD-Client>,
-L<https://github.com/trwyant/perl-Astro-SIMBAD-Client/issues>, or in
-electronic mail to the author.
-
 =head1 AUTHOR
 
 Thomas R. Wyant, III (F<wyant at cpan dot org>)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2011-2025 by Thomas R. Wyant, III
+Copyright (C) 2011-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
-of the licenses in the files F<LICENSE-Artistic> and F<LICENSE-GNU>.
+of the licenses in the directory LICENSES.
 
 This program is distributed in the hope that it will be useful, but
 without any warranty; without even the implied warranty of
