@@ -110,7 +110,7 @@ BEGIN {
 	|| sub { return $_[0] };
 }
 
-our $VERSION = '0.034';
+our $VERSION = '0.035';
 
 our @CARP_NOT = qw{Astro::SIMBAD::Client::WSQueryInterfaceService};
 
@@ -192,7 +192,8 @@ my %static = (
     },
     post => 1,
 ##    server => 'simweb.u-strasbg.fr',
-    server => 'simbad.u-strasbg.fr',
+##    server => 'simbad.u-strasbg.fr',
+    server => $ENV{ASTRO_SIMBAD_CLIENT_SERVER} || 'simbad.u-strasbg.fr',
     type => 'txt',
     url_args => {},
     verbatim => 0,
@@ -623,7 +624,7 @@ EOD
 	if ( $self->get( 'emulate_soap_queries' ) ) {
 	    my $type = $self->get( 'type' );
 	    my $code = $make_script{$type} || sub {
-		my ( $self, $query, @args ) = @_;
+		my ( undef, $query, @args ) = @_;	# Invocant unused
 		return "query $query @args\n";
 	    };
 	    return $self->_script(
@@ -949,7 +950,8 @@ it sets the default value of the attribute.
 	    $ckpn :
 	    sub {+sprintf '%d', $ckpn->(@_) + .5}),
 	format => sub {
-	    my ($self, $name, $val, $key) = @_;
+##	    my ( $self, $name, $val, $key ) = @_;
+	    my ( $self, undef, $val ) = @_;	# Name and key unused
 	    if ($val !~ m/\W/ && (my $code = eval {
 			$self->_get_coderef ($val)})) {
 		$val = $code->();
@@ -957,7 +959,8 @@ it sets the default value of the attribute.
 	    $val;
 	},
 	parser => sub {
-	    my ($self, $name, $val, $key) = @_;
+##	    my ( $self, $name, $val, $key ) = @_;
+	    my ( $self, undef, $val ) = @_;	# Name and key unused
 	    if (!ref $val) {
 		unless ($val =~ m/::/) {
 		    my $pkg = $self->_parse_subroutine_name ($val);
@@ -1165,6 +1168,7 @@ sub _callers_caller {
 #
 #	This method returns true if the deprecation is in progress. In
 #	practice this means the %deprecate value is defined.
+#	This is currently unused and commented out
 
 {
 
@@ -1175,7 +1179,7 @@ sub _callers_caller {
     );
 
     sub _deprecation_notice {
-	my ( $self, $type, $name, $repl ) = @_;
+	my ( undef, $type, $name, $repl ) = @_;	# Invocant unused
 	$deprecate{$type} or return;
 	$deprecate{$type}{$name} or return;
 	my $msg = sprintf 'The %s %s is %s', $name, $type,
@@ -1191,12 +1195,18 @@ sub _callers_caller {
 	return;
     }
 
+=begin comment
+
     sub _deprecation_in_progress {
-	my ( $self, $type, $name ) = @_;
+	my ( undef, $type, $name ) = @_;	# Invocant unused
 	$deprecate{$type} or return;
 	return defined $deprecate{$type}{$name};
     }
 
+=end comment
+
+=cut
+
 }
 
 #	$ref = $self->_get_coderef ($string)
@@ -1530,7 +1540,9 @@ This attribute specifies the server to be used. As of January 26 2007,
 only 'simbad.u-strasbg.fr' is valid, since as of that date Harvard
 University has not yet converted their mirror to SIMBAD 4.
 
-The default is 'simbad.u-strasbg.fr'.
+The default is the value of environment variable
+ASTRO_SIMBAD_CLIENT_SERVER, or C<'simbad.u-strasbg.fr'> if the
+environment variable is not set.
 
 =for html <a name="type"></a>
 
@@ -1575,6 +1587,15 @@ The default is 0 (i.e. false)
 
 =back
 
+=head1 ENVIRONMENT
+
+=head2 ASTRO_SIMBAD_CLIENT_SERVER
+
+If assigned a true value, this environment variable specifies the
+default for the C<'server'> attribute. It is read when the module is
+loaded. If you want to change the default after the module has been
+loaded, make a static call to C<set()>.
+
 =head1 AUTHOR
 
 Thomas R. Wyant, III (F<wyant at cpan dot org>)
